# project-config

[![PyPI][pypi-version-badge-link]][pypi-link]
[![Python versions][pypi-pyversions-badge-link]][pypi-link]
[![License][license-image]][license-link]
[![Tests][tests-image]][tests-link]
[![Coverage][coverage-image]][coverage-link]
[![Downloads][pypi-downloads-image]][pypi-downloads-link]


> Note for developers: This project is under heavy development.
The testing and reporter APIs may change without warning before the
first stable release (v1), but configuration, CLI and plugins are
guaranteed to be backwards compatible, so you can safely write
styles now! :+1:

## [Documentation](https://mondeja.github.io/project-config/latest/)

[pypi-link]: https://pypi.org/project/project-config
[pypi-version-badge-link]: https://img.shields.io/pypi/v/project-config?logo=pypi&logoColor=white
[pypi-pyversions-badge-link]: https://img.shields.io/pypi/pyversions/project-config?logo=python&logoColor=white
[license-image]: https://img.shields.io/pypi/l/project-config?color=light-green&logo=freebsd&logoColor=white
[license-link]: https://github.com/mondeja/project-config/blob/master/LICENSE
[tests-image]: https://img.shields.io/github/workflow/status/mondeja/project-config/CI?logo=github&label=tests
[tests-link]: https://github.com/mondeja/project-config/actions?query=workflow%3ACI
[pypi-downloads-image]: https://img.shields.io/pypi/dm/project-config?logo=pypi&logoColor=white
[pypi-downloads-link]: https://pypistats.org/packages/project-config
[coverage-image]: https://img.shields.io/coveralls/github/mondeja/project-config?logo=coveralls
[coverage-link]: https://coveralls.io/github/mondeja/project-config
